@@ -23,7 +23,7 @@ from cubicweb.entities.adapters import ITreeAdapter
 from cubicweb.__pkginfo__ import numversion as cubicweb_version
 
 if cubicweb_version < (3, 28):
-    from cubicweb.view import EntityAdapter
+    from cubicweb_web.view import EntityAdapter
 else:
     from cubicweb.entity import EntityAdapter
 
