@@ -26,11 +26,11 @@ from cubicweb.predicates import (is_instance, has_related_entities, one_line_rse
                                  score_entity, match_edited_type,
                                  match_form_params, match_user_groups,
                                  ExpectedValuePredicate)
-from cubicweb.view import View, AnyRsetView, EntityView
-from cubicweb.web import Redirect
-from cubicweb.web import (action, component, formfields as ff, formwidgets as fw,
+from cubicweb_web.view import View, AnyRsetView, EntityView
+from cubicweb_web import Redirect
+from cubicweb_web import (action, component, formfields as ff, formwidgets as fw,
                           facet)
-from cubicweb.web.views import (actions, autoform, editcontroller, formrenderers, uicfg,
+from cubicweb_web.views import (actions, autoform, editcontroller, formrenderers, uicfg,
                                 ibreadcrumbs, forms, tabs, cwsources, treeview, baseviews)
 
 from cubicweb_skos import (
