@@ -18,7 +18,7 @@
 from io import BytesIO
 
 from cubicweb.predicates import adaptable
-from cubicweb.view import EntityView
+from cubicweb_web.view import EntityView
 
 from cubicweb_skos.rdfio import default_graph
 
