@@ -16,7 +16,7 @@
 """cubicweb-skos sobjects tests"""
 
 from cubicweb import Unauthorized
-from cubicweb.devtools import testlib
+from cubicweb.devtools import testlib, BASE_URL
 
 from unittest_sobjects import silent_logging
 
@@ -37,7 +37,7 @@ class SKOSSchemaTC(testlib.CubicWebTC):
             scheme = cnx.create_entity('ConceptScheme')
             cnx.commit()
             # title default to cwuri
-            self.assertEqual(scheme.dc_title(), 'http://testing.fr/cubicweb/%s' % scheme.eid)
+            self.assertEqual(scheme.dc_title(), f'{BASE_URL}{scheme.eid}')
 
     def test_concept_multiple_schemes(self):
         with self.admin_access.repo_cnx() as cnx:
