@@ -19,7 +19,7 @@ import io
 import logging
 from contextlib import contextmanager
 
-from cubicweb.devtools import testlib
+from cubicweb.devtools import testlib, BASE_URL
 
 from cubicweb_skos.dataimport import dump_relations
 
@@ -208,14 +208,14 @@ class LCSVImportTC(testlib.CubicWebTC):
         self.assertEqual(label.label, "Vie politique")
         self.assertEqual(len(concept1.preferred_label), 1)
         self.assertEqual(len(concept1.narrower_concept), 2)
-        self.assertEqual(concept1.cwuri, 'http://testing.fr/cubicweb/%s' % concept1.eid)
+        self.assertEqual(concept1.cwuri, f"{BASE_URL}{concept1.eid}")
         concept2 = cnx.find('Concept',
                             definition=u"Création volontaire ou en application de la loi").one()
         self.assertEqual(concept2.broader_concept[0], concept1)
-        self.assertEqual(concept2.cwuri, 'http://testing.fr/cubicweb/%s' % concept2.eid)
+        self.assertEqual(concept2.cwuri, f"{BASE_URL}{concept2.eid}")
         label = cnx.find('Label', label=u"Vie politique").one()
         self.assertEqual(label.language_code, label_lang)
-        self.assertEqual(label.cwuri, 'http://testing.fr/cubicweb/%s' % label.eid)
+        self.assertEqual(label.cwuri, f"{BASE_URL}{label.eid}")
 
 
 if __name__ == '__main__':
