@@ -20,7 +20,7 @@ import io
 from io import BytesIO
 from tempfile import NamedTemporaryFile
 
-from cubicweb.web import Redirect
+from cubicweb_web import Redirect
 from cubicweb.devtools import testlib
 
 from cubicweb_skos.rdfio import default_graph
